# A Python interface to MVA SAS
## Overview
This module allows a python process to connect to SAS 9.4 and run SAS code, generated by the supplied object and methods or explicitly user written, and returns results as text, HTML5 documents (via SAS ODS), or as Pandas Data Frames. It supports running analytics and returning the resulting graphics and result data. It can convert between SAS Data Sets and Pandas Data Frames. It has multiple access methods which allow it to connect to local or remote Linux SAS, IOM SAS on Windows or Linux (Including Grid Manager), and local PC SAS. It can run w/in Jupyter Notebooks, in line mode python or in python batch scripts. It is expected that the user community can and will contribute enhancements. 

# Prerequisites 
This module requires Python3.x or above. It also requires SAS 9.4 or above. 

# Installation

This module can be installed via pip. This will pull down the latest PyPI package and install it.

    pip install saspy

However, if that's too easy, you can also download a specific release from
[SASpy project releases page](https://github.com/sassoftware/saspy/releases), or just clone
the repo and and instll from that. To install a given release, use the following, 
where the X.X.X is the release version you want.

    pip install https://github.com/sassoftware/saspy/releases/download/vX.X.X/saspy.tar.gz
    
# Getting Started     

All of the doc, including install and configuration information can be found at
[sassoftware.github.io/saspy](https://sassoftware.github.io/saspy/).

Also, example Notebooks and use cases can be found at
[sassoftware/saspy-examples](https://github.com/sassoftware/saspy-examples/).   

# Contributing
The [Contributor Agreement](https://github.com/sassoftware/saspy/blob/master/ContributorAgreement.txt) details on how to make contributions to this project. The [Contributing](https://github.com/sassoftware/saspy/blob/master/CONTRIBUTING.md) file explains the rules and conventions to follow while Contributing to this project.

# Licensing 
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at [LICENSE.txt](https://github.com/sassoftware/saspy/blob/master/LICENSE) 

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

# Additional Resources
- [Python Website](http://www.python.org/)
- [SASPy Documentation](https://sassoftware.github.io/saspy/).
- [SASPy Examples](https://github.com/sassoftware/saspy-examples) 


Copyright SAS Institute
